.. web-payments-connector documentation master file, created by
   sphinx-quickstart on Wed Apr 11 20:50:23 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to web-payments-connector's documentation!
==================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install.rst
   django.rst
   usage.rst
   refund.rst
   preauth.rst
   backends.rst



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
